@@ -164,7 +164,9 @@ sub Run {
         },
     );
 
+    # get needed objects
     $Self->{DBObject} = $Kernel::OM->Get('Kernel::System::DB');
+
     my $DBCanConnect = $Self->{DBObject}->Connect();
 
     # Restore original behaviour of Kernel::System::DB for all objects created in future
@@ -177,14 +179,14 @@ sub Run {
         my $LayoutObject = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
         if ( !$DBCanConnect ) {
             $LayoutObject->CustomerFatalError(
-                Comment => 'Please contact your administrator',
+                Comment => $LayoutObject->{LanguageObject}->Translate('Please contact your administrator'),
             );
             return;
         }
         if ( $Self->{ParamObject}->Error() ) {
             $LayoutObject->CustomerFatalError(
                 Message => $Self->{ParamObject}->Error(),
-                Comment => 'Please contact your administrator',
+                Comment => $LayoutObject->{LanguageObject}->Translate('Please contact your administrator'),
             );
             return;
         }
@@ -286,7 +288,8 @@ sub Run {
                         What => 'Message',
                         )
                         || $AuthObject->GetLastErrorMessage()
-                        || 'Login failed! Your user name or password was entered incorrectly.',
+                        || $LayoutObject->{LanguageObject}
+                        ->Translate('Login failed! Your user name or password was entered incorrectly.'),
                     User        => $PostUser,
                     LoginFailed => 1,
                     %Param,
@@ -329,7 +332,9 @@ sub Run {
                 Output => \$LayoutObject->CustomerLogin(
                     Title => 'Panic!',
                     Message =>
-                        'Authentication succeeded, but no customer record is found in the customer backend. Please contact your administrator.',
+                        $LayoutObject->{LanguageObject}->Translate(
+                        'Authentication succeeded, but no customer record is found in the customer backend. Please contact your administrator.'
+                        ),
                     %Param,
                 ),
             );
@@ -466,7 +471,7 @@ sub Run {
             # show login screen
             print $LayoutObject->CustomerLogin(
                 Title   => 'Logout',
-                Message => 'Session invalid. Please log in again.',
+                Message => $LayoutObject->{LanguageObject}->Translate('Session invalid. Please log in again.'),
                 %Param,
             );
             return;
@@ -495,11 +500,14 @@ sub Run {
             },
         );
 
+        $Kernel::OM->ObjectsDiscard( Objects => ['Kernel::Output::HTML::Layout'] );
         my $LayoutObject = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
 
         # remove session id
         if ( !$Self->{SessionObject}->RemoveSessionID( SessionID => $Param{SessionID} ) ) {
-            $LayoutObject->CustomerFatalError( Comment => 'Please contact your administrator' );
+            $LayoutObject->CustomerFatalError(
+                Comment => $LayoutObject->{LanguageObject}->Translate('Please contact your administrator')
+            );
             return;
         }
 
@@ -541,7 +549,7 @@ sub Run {
             $LayoutObject->Print(
                 Output => \$LayoutObject->CustomerLogin(
                     Title   => 'Login',
-                    Message => 'Feature not active!',
+                    Message => $LayoutObject->{LanguageObject}->Translate('Feature not active!'),
                 ),
             );
             return;
@@ -580,7 +588,8 @@ sub Run {
             $LayoutObject->Print(
                 Output => \$LayoutObject->CustomerLogin(
                     Title   => 'Login',
-                    Message => 'Sent password reset instructions. Please check your email.',
+                    Message => $LayoutObject->{LanguageObject}
+                        ->Translate('Sent password reset instructions. Please check your email.'),
                 ),
             );
             return;
@@ -614,14 +623,15 @@ sub Run {
             );
             if ( !$Sent ) {
                 $LayoutObject->FatalError(
-                    Comment => 'Please contact your administrator'
+                    Comment => $LayoutObject->{LanguageObject}->Translate('Please contact your administrator'),
                 );
                 return;
             }
             $LayoutObject->Print(
                 Output => \$LayoutObject->CustomerLogin(
                     Title   => 'Login',
-                    Message => 'Sent password reset instructions. Please check your email.',
+                    Message => $LayoutObject->{LanguageObject}
+                        ->Translate('Sent password reset instructions. Please check your email.'),
                     %Param,
                 ),
             );
@@ -660,7 +670,8 @@ sub Run {
                 Output => \$LayoutObject->CustomerLogin(
                     Title => 'Login',
                     Message =>
-                        "Reset password unsuccessful. Please contact your administrator",
+                        $LayoutObject->{LanguageObject}
+                        ->Translate('Reset password unsuccessful. Please contact your administrator'),
                     User => $User,
                 ),
             );
@@ -715,7 +726,7 @@ sub Run {
             $LayoutObject->Print(
                 Output => \$LayoutObject->CustomerLogin(
                     Title   => 'Login',
-                    Message => 'Feature not active!',
+                    Message => $LayoutObject->{LanguageObject}->Translate('Feature not active!'),
                 ),
             );
             return;
@@ -748,7 +759,8 @@ sub Run {
                 Output => \$LayoutObject->CustomerLogin(
                     Title => 'Login',
                     Message =>
-                        'This email address already exists. Please log in or reset your password.',
+                        $LayoutObject->{LanguageObject}
+                        ->Translate('This e-mail address already exists. Please log in or reset your password.'),
                     UserTitle     => $GetParams{UserTitle},
                     UserFirstname => $GetParams{UserFirstname},
                     UserLastname  => $GetParams{UserLastname},
@@ -773,7 +785,9 @@ sub Run {
                 $Self->{LogObject}->Log(
                     Priority => 'error',
                     Message =>
-                        'The customer panel mail address whitelist contains the invalid regular expression $WhitelistEntry, please check and correct it.',
+                        $LayoutObject->{LanguageObject}->Translate(
+                        'The customer panel mail address whitelist contains the invalid regular expression $WhitelistEntry, please check and correct it.'
+                        ),
                 );
             }
             elsif ( $GetParams{UserEmail} =~ $Regex ) {
@@ -787,7 +801,9 @@ sub Run {
                 $Self->{LogObject}->Log(
                     Priority => 'error',
                     Message =>
-                        'The customer panel mail address blacklist contains the invalid regular expression $BlacklistEntry, please check and correct it.',
+                        $LayoutObject->{LanguageObject}->Translate(
+                        'The customer panel mail address blacklist contains the invalid regular expression $BlacklistEntry, please check and correct it.'
+                        ),
                 );
             }
             elsif ( $GetParams{UserEmail} =~ $Regex ) {
@@ -801,7 +817,8 @@ sub Run {
                 Output => \$LayoutObject->CustomerLogin(
                     Title => 'Login',
                     Message =>
-                        'This email address is not allowed to register. Please contact support staff.',
+                        $LayoutObject->{LanguageObject}
+                        ->Translate('This email address is not allowed to register. Please contact support staff.'),
                     UserTitle     => $GetParams{UserTitle},
                     UserFirstname => $GetParams{UserFirstname},
                     UserLastname  => $GetParams{UserLastname},
@@ -989,7 +1006,7 @@ sub Run {
             $LayoutObject->Print(
                 Output => \$LayoutObject->CustomerLogin(
                     Title   => 'Login',
-                    Message => $Self->{SessionObject}->SessionIDErrorMessage(),
+                    Message => $LayoutObject->{LanguageObject}->Translate( $Self->{SessionObject}->SessionIDErrorMessage() ),
                     %Param,
                 ),
             );
@@ -1018,7 +1035,7 @@ sub Run {
             $LayoutObject->Print(
                 Output => \$LayoutObject->CustomerLogin(
                     Title   => 'Panic!',
-                    Message => 'Panic! Invalid Session!!!',
+                    Message => $LayoutObject->{LanguageObject}->Translate('Panic! Invalid Session!!!'),
                     %Param,
                 ),
             );
@@ -1036,7 +1053,9 @@ sub Run {
                 Message =>
                     "Module Kernel::Modules::$Param{Action} not registered in Kernel/Config.pm!",
             );
-            $LayoutObject->CustomerFatalError( Comment => 'Please contact your administrator' );
+            $LayoutObject->CustomerFatalError(
+                Comment => $LayoutObject->{LanguageObject}->Translate('Please contact your administrator'),
+            );
             return;
         }
 
@@ -1098,6 +1117,7 @@ sub Run {
             },
         );
 
+        $Kernel::OM->ObjectsDiscard( Objects => ['Kernel::Output::HTML::Layout'] );
         my $LayoutObject = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
 
         # updated last request time
@@ -1218,7 +1238,9 @@ sub Run {
         },
     );
     my $LayoutObject = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
-    $LayoutObject->CustomerFatalError( Comment => 'Please contact your administrator' );
+    $LayoutObject->CustomerFatalError(
+        Comment => $LayoutObject->{LanguageObject}->Translate('Please contact your administrator'),
+    );
     return;
 }
 
